@@ -48,7 +48,14 @@ struct _ClutterBackend
 
   ClutterDeviceManager *device_manager;
 
-  ClutterBackendPrivate *priv;
+  cairo_font_options_t *font_options;
+
+  gchar *font_name;
+
+  gfloat units_per_em;
+  gint32 units_serial;
+
+  GList *event_translators;
 };
 
 struct _ClutterBackendClass
